<?php
use yii\db\Migration;
use common\models\Category;

class m160830_105840_category extends Migration
{

    public function safeUp()
    {
        $tableOptions = null;
        if ($this->db->driverName === 'mysql') {
            $tableOptions = 'CHARACTER SET utf8 COLLATE utf8_unicode_ci ENGINE=InnoDB';
        }

        $this->createTable('{{%category}}', [
            'id' => $this->primaryKey(),
            'name' => $this->string(32)->notNull(),
            'slug' => $this->string(32)->notNull(),
            'description' => $this->string(512),
            'image_url' => $this->string(1024),
            'image_path' => $this->string(1024),
            'status' => $this->smallInteger()->notNull()->defaultValue(Category::STATUS_ACTIVE),
            'created_at' => $this->integer(),
            'updated_at' => $this->integer()
        ], $tableOptions);

        $this->createTable('{{%category_files}}', [
            'id' => $this->primaryKey(),
            'category_id' => $this->integer()->notNull(),
            'code' => $this->string(10)->notNull(),
            'type' => $this->integer()->notNull(),
            'name' => $this->string(32)->notNull(),
            'created_at' => $this->integer(),
            'updated_at' => $this->integer()
        ], $tableOptions);

        $this->createIndex('idx_category_name', '{{%category}}', 'name');
        $this->createIndex('idx_category_slug', '{{%category}}', 'slug');
        $this->createIndex('idx_category_files_category_id', '{{%category_files}}', 'category_id');
        $this->createIndex('idx_category_files_code', '{{%category_files}}', 'code');
        $this->createIndex('idx_category_files_name', '{{%category_files}}', 'name');

        $this->addForeignKey('fk_category', '{{%category_files}}', 'category_id', '{{%category}}', 'id', 'RESTRICT',
            'RESTRICT');
    }

    public function safeDown()
    {
        $this->dropForeignKey('fk_category', '{{%category_files}}');

        $this->dropIndex('idx_category_files_name', '{{%category_files}}');
        $this->dropIndex('idx_category_files_code', '{{%category_files}}');
        $this->dropIndex('idx_category_files_category_id', '{{%category_files}}');
        $this->dropIndex('idx_category_slug', '{{%category}}');
        $this->dropIndex('idx_category_name', '{{%category}}');
        
        $this->dropTable('{{%category_files}}');
        $this->dropTable('{{%category}}');
    }

}
