<?php

namespace common\models;

use Yii;
use yii\behaviors\SluggableBehavior;
use yii\behaviors\TimestampBehavior;

/**
 * This is the model class for table "{{%theme}}".
 *
 * @property integer $id
 * @property integer $category_id
 * @property string $code
 * @property string $slug
 * @property string $name
 * @property string $description
 * @property integer $status
 * @property integer $created_at
 * @property integer $updated_at
 *
 * @property Category $category
 * @property ThemeFiles[] $themeFiles
 * @property Website[] $websites
 */
class Theme extends \yii\db\ActiveRecord
{
    const STATUS_ACTIVE = 1;
    const STATUS_IN_ACTIVE = 0;
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return '{{%theme}}';
    }

    public function behaviors()
    {
        return [
            [
                'class' => SluggableBehavior::className(),
                'attribute' => 'name',
                'immutable' => true
            ],
            [
                'class' => TimestampBehavior::className(),
                'createdAtAttribute' => 'created_at',
                'updatedAtAttribute' => 'updated_at'
            ]
        ];
    }
    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['category_id', 'code', 'slug', 'name', 'status'], 'required'],
            [['category_id', 'status', 'created_at', 'updated_at'], 'integer'],
            [['name', 'slug', 'code'],'trim'],
            [
                ['name', 'slug', 'code'],
                'match',
                'pattern' => '/^[a-zA-Z\s0-9_-]+$/',
                'message' => 'only, alphanumeric characters, underscores and dashes are allowed.'
            ],
            [['code', 'slug', 'name'], 'string', 'max' => 32],
            [['description'], 'string', 'max' => 512],
            [['category_id'], 'exist', 'skipOnError' => true, 'targetClass' => Category::className(), 'targetAttribute' => ['category_id' => 'id']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('common', 'ID'),
            'category_id' => Yii::t('common', 'Category ID'),
            'code' => Yii::t('common', 'Code'),
            'slug' => Yii::t('common', 'Slug'),
            'name' => Yii::t('common', 'Name'),
            'description' => Yii::t('common', 'Description'),
            'status' => Yii::t('common', 'Status'),
            'created_at' => Yii::t('common', 'Created At'),
            'updated_at' => Yii::t('common', 'Updated At'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getCategory()
    {
        return $this->hasOne(Category::className(), ['id' => 'category_id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getThemeFiles()
    {
        return $this->hasMany(ThemeFiles::className(), ['theme_code' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getWebsites()
    {
        return $this->hasMany(Website::className(), ['theme_id' => 'id']);
    }

   /**
     * @inheritdoc
     * @return \common\models\query\ThemeQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new \common\models\query\ThemeQuery(get_called_class());
    }
    /**
     * List all status
     * @return array
     */
    public static function statuses()
    {
        return [
            self::STATUS_ACTIVE => Yii::t('common', 'Active'),
            self::STATUS_IN_ACTIVE => Yii::t('common', 'In Active'),
        ];
    }
}
