<?php

namespace common\models;

use Yii;
use yii\behaviors\TimestampBehavior;

/**
 * This is the model class for table "{{%theme_files}}".
 *
 * @property integer $id
 * @property integer $theme_code
 * @property integer $file_code
 * @property string $base_url
 * @property string $base_path
 * @property integer $created_at
 * @property integer $updated_at
 * @property string $filePath
 *
 * @property CategoryFiles $fileCode
 * @property Theme $themeCode
 */
class ThemeFiles extends \yii\db\ActiveRecord
{
    /*
     * @var file upload
     */
    public $file;
    /*
     * @var file upload
     */
    public $fileContent;
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return '{{%theme_files}}';
    }

    public function behaviors()
    {
        return [
            [
                'class' => TimestampBehavior::className(),
                'createdAtAttribute' => 'created_at',
                'updatedAtAttribute' => 'updated_at'
            ]
        ];
    }
    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['theme_code', 'file_code','file'], 'required'],
            [['theme_code', 'file_code','fileContent'], 'string'],
            [['created_at', 'updated_at'], 'integer'],
            [['file_code'], 'exist', 'skipOnError' => true, 'targetClass' => CategoryFiles::className(), 'targetAttribute' => ['file_code' => 'id']],
            [['theme_code'], 'exist', 'skipOnError' => true, 'targetClass' => Theme::className(), 'targetAttribute' => ['theme_code' => 'id']],
            [['file'],'file'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('common', 'ID'),
            'theme_code' => Yii::t('common', 'Theme Code'),
            'file_code' => Yii::t('common', 'File Code'),
            'base_url' => Yii::t('common', 'Base Url'),
            'base_path' => Yii::t('common', 'Base Path'),
            'created_at' => Yii::t('common', 'Created At'),
            'updated_at' => Yii::t('common', 'Updated At'),
            'file' => Yii::t('common','Choose your file to upload')
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getFileCode()
    {
        return $this->hasOne(CategoryFiles::className(), ['id' => 'file_code']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getThemeCode()
    {
        return $this->hasOne(Theme::className(), ['id' => 'theme_code']);
    }

    public static function getFilePath($theme_code,$file_code)
    {
        return yii::getAlias('@storage/private/theme-assets/') .$theme_code . '/' .$file_code;

    }
    
    /**
     * @inheritdoc
     * @return \common\models\query\ThemeFilesQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new \common\models\query\ThemeFilesQuery(get_called_class());
    }

    public static function isFileExist($theme_code,$file_code)
    {
        return file_exists(self::getFilePath($theme_code,$file_code));
    }

}
